@@ -32,7 +32,7 @@ class TestMbIntegration(unittest.TestCase):
         for i in ["01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13"]:
             row = {'NGDC_ID': "1111" + i, 'CREATED_BY': "klaus", 'DOWNLOAD_URL': "noaa.com"}
             self.mb_service.insert_row(table="SURVEY_REFERENCE", row=row)
-        size = self.mb_service.get_table_size("SURVEY_REFERENCE")
+        size = self.mb_service.get_survey_count("SURVEY_REFERENCE")
         self.assertEqual(size, 13)
 
     def test_survey_page_retrieval(self):
